@@ -1,26 +1,11 @@
 <?php
-/*
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * This software consists of voluntary contributions made by many individuals
- * and is licensed under the MIT license.
- */
 
 declare(strict_types=1);
 
 namespace ProxyManager\ProxyGenerator\AccessInterceptorScopeLocalizer\MethodGenerator\Util;
 
 use ProxyManager\Generator\MethodGenerator;
+use ProxyManager\Generator\Util\ProxiedMethodReturnExpression;
 use Zend\Code\Generator\PropertyGenerator;
 
 /**
@@ -40,19 +25,19 @@ class InterceptorGenerator
      * @param \ProxyManager\Generator\MethodGenerator $method
      * @param \Zend\Code\Generator\PropertyGenerator  $prefixInterceptors
      * @param \Zend\Code\Generator\PropertyGenerator  $suffixInterceptors
-     *
-     * @return string
+     * @param \ReflectionMethod|null                  $originalMethod
      */
     public static function createInterceptedMethodBody(
         string $methodBody,
         MethodGenerator $method,
         PropertyGenerator $prefixInterceptors,
-        PropertyGenerator $suffixInterceptors
+        PropertyGenerator $suffixInterceptors,
+        ?\ReflectionMethod $originalMethod
     ) : string {
-        $name               = var_export($method->getName(), true);
-        $prefixInterceptors = $prefixInterceptors->getName();
-        $suffixInterceptors = $suffixInterceptors->getName();
-        $params             = [];
+        $name                   = var_export($method->getName(), true);
+        $prefixInterceptorsName = $prefixInterceptors->getName();
+        $suffixInterceptorsName = $suffixInterceptors->getName();
+        $params                 = [];
 
         foreach ($method->getParameters() as $parameter) {
             $parameterName = $parameter->getName();
@@ -61,23 +46,23 @@ class InterceptorGenerator
 
         $paramsString = 'array(' . implode(', ', $params) . ')';
 
-        return "if (isset(\$this->$prefixInterceptors" . "[$name])) {\n"
+        return "if (isset(\$this->$prefixInterceptorsName" . "[$name])) {\n"
             . "    \$returnEarly       = false;\n"
-            . "    \$prefixReturnValue = \$this->$prefixInterceptors" . "[$name]->__invoke("
+            . "    \$prefixReturnValue = \$this->$prefixInterceptorsName" . "[$name]->__invoke("
             . "\$this, \$this, $name, $paramsString, \$returnEarly);\n\n"
             . "    if (\$returnEarly) {\n"
-            . "        return \$prefixReturnValue;\n"
+            . '        ' . ProxiedMethodReturnExpression::generate('$prefixReturnValue', $originalMethod) . "\n"
             . "    }\n"
             . "}\n\n"
             . $methodBody . "\n\n"
-            . "if (isset(\$this->$suffixInterceptors" . "[$name])) {\n"
+            . "if (isset(\$this->$suffixInterceptorsName" . "[$name])) {\n"
             . "    \$returnEarly       = false;\n"
-            . "    \$suffixReturnValue = \$this->$suffixInterceptors" . "[$name]->__invoke("
+            . "    \$suffixReturnValue = \$this->$suffixInterceptorsName" . "[$name]->__invoke("
             . "\$this, \$this, $name, $paramsString, \$returnValue, \$returnEarly);\n\n"
             . "    if (\$returnEarly) {\n"
-            . "        return \$suffixReturnValue;\n"
+            . '        ' . ProxiedMethodReturnExpression::generate('$suffixReturnValue', $originalMethod) . "\n"
             . "    }\n"
             . "}\n\n"
-            . "return \$returnValue;";
+            . ProxiedMethodReturnExpression::generate('$returnValue', $originalMethod);
     }
 }
